# setClassUnion("vectororNULL", c("vector","NULL"))
setClassUnion("OptionalParameter", c("Parameter","NULL"))
